package sklep.rest;

import org.springframework.http.HttpStatusCode;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.server.ResponseStatusException;
import sklep.model.Product;
import sklep.photo.PhotoUtil;
import sklep.repository.ProductRepository;

import java.util.List;

// @RestController odpowiada adnotacji @Controller z dodatkową adnotacją @ResponseBody
// Inaczej mówiąc, metody nie zwracają nazw szablonów, lecz dane, które mają być odesłane do klienta.
@RestController
@RequestMapping("/rest/products")
public class ProductEndpoint {
    private ProductRepository productRepository;
    private PhotoUtil photoUtil;

    // Tutaj stosujemy wstrzykiwanie przez konstruktor.
    public ProductEndpoint(ProductRepository productRepository, PhotoUtil photoUtil) {
        this.productRepository = productRepository;
        this.photoUtil = photoUtil;
    }

    @GetMapping
    public List<Product> getProducts() {
        return productRepository.findAll();
    }

    @GetMapping("/{id}")
    public Product getProduct(@PathVariable int id) {
        return productRepository.findById(id).orElseThrow(
                () -> new ResponseStatusException(HttpStatusCode.valueOf(404),
                        "Brak produktu o numerze " + id));
    }

}
